
rm(list=ls())
libs <- c("tidyverse", "lme4", "sjPlot", "sjmisc", "merTools")
lapply(libs, require, character.only = TRUE)

setwd("~/projects/founder/eco-apps")

# import data
plotdata <- read.csv(file = "nucl-data.csv")


# useful functions
## scale variables for models                
scale_vars = function (x) {
     
     (x-mean(x)) / sd(x)     
}

## from https://sebastiansauer.github.io/convert_logit2prob/
logit2prob <- function(logit){
     odds <- exp(logit)
     prob <- odds / (1 + odds)
     return(prob)
}

# scale / transform data    
plotdata = plotdata %>%
     dplyr::mutate(across(c(n_c1, conifer_index, nr_conifer_index, gc_litter, gc_li_cobb, pipj_pre_index, pipj_nr_index, 
                            shrub_vol_plot, shrub_pct, slope, elev), scale_vars, .names = "{col}_sc"))  %>%
     dplyr::mutate(dist2 = dist_pl_edge^2)         


# models

presence_pipj <- glmer(presence_pipj ~

# presence_pipj_es <- glmer(presence_pipj ~
                               
                               # planted seed distance
                               dist_pl_edge +
                               
                               # competitors (low)
                               shrub_vol_plot_sc + n_c1_sc +
                               
                               # other seed sources
                               pipj_pre_index_sc + pipj_nr_index_sc + 
                               
                               (1|transect), data = plotdata , family = binomial(link = "logit"))
                              # (1|transect), data = plotdata %>% filter(loc %in% c("BC", "CL")), family = binomial(link = "logit"))

# density_pipj <- glmer.nb(pipj_n_c2 ~
                              
density_pipj_es <- glmer.nb(pipj_n_c2 ~
                              
                              # planted seed distance
                              dist_pl_edge +
                              
                              # competitors (low)
                              shrub_vol_plot_sc + n_c1_sc +
                              
                              # other seed sources
                              pipj_pre_index_sc + pipj_nr_index_sc + 
                              
                              # (1|transect), data = plotdata)
                              (1|transect), data = plotdata %>% filter(loc %in% c("BC", "CL")), family = binomial(link = "logit"))


presence_all <- glmer(presence_n_c2 ~ 
# presence_all_es <- glmer(presence_n_c2 ~ 
                           
                           # plantation seed distance
                           dist_pl_edge +
                           
                           # competitors (low)
                           shrub_vol_plot_sc + n_c1_sc +
                           
                           # other seed sources
                           conifer_index_sc + nr_conifer_index_sc +
                           
                           (1|transect), data = plotdata, family = binomial(link = "logit"))
                         # (1|transect), data = plotdata %>% filter(loc %in% c("BC", "CL")), family = binomial(link = "logit"))

# density_all <- glmer.nb(as.integer(n_c2) ~
                             
density_all_es <- glmer.nb(as.integer(n_c2) ~
                             
                             # plantation seed distance
                             dist_pl_edge +
                             
                             # competitors (low)
                             shrub_vol_plot_sc + n_c1_sc +
                             
                             # other seed sources
                             conifer_index_sc + nr_conifer_index_sc +
                             
                             # other
                             gc_litter_sc +
                             
                             # (1|transect), data = plotdata)
                              (1|transect), data = plotdata %>% filter(loc %in% c("BC", "CL")), family = binomial(link = "logit"))


# summary stats plot

plotdata <- plotdata %>%
     dplyr::mutate(dist_cat = as.character(dist_pl_edge) ) %>%
     dplyr::mutate(dist_cat = case_when(
          
          dist_pl_edge == 30 & loc == "BC" ~ "30-35",     
          dist_pl_edge == 35 & loc == "BC" ~ "30-35", 
          dist_pl_edge == 50 & loc == "BC" ~ "50-70", 
          dist_pl_edge == 60 & loc == "BC" ~ "50-70", 
          dist_pl_edge == 70 & loc == "BC" ~ "50-70",
          TRUE ~ dist_cat
     )) %>%      
     dplyr::mutate(loc_type = case_when(
          group_in_loc == "BC_G1" ~ "Low Elev",
          group_in_loc == "BC_G2" ~ "Low Elev",
          group_in_loc == "BC_G3" ~ "High Elev",
          group_in_loc == "BC_G4" ~ "High Elev", 
          TRUE ~ as.character(loc)) )

summ_stats <- plotdata %>%
     group_by(loc, dist_cat) %>%
     dplyr::summarize(mean_sdl = (mean(n_c2) %>% round(digits = 1)), 
                      sd_sdl = (sd(n_c2) %>% round(digits = 1)),
                      med_sdl = (median(n_c2) %>% round(digits = 1)), 
                      
                      mean_sdl_pipj = (mean(pipj_n_c2) %>% round(digits = 1)), 
                      sd_sdl_pipj = (sd(pipj_n_c2) %>% round(digits = 1)),
                      med_sdl_pipj = (median(pipj_n_c2) %>% round(digits = 1)),
                      
                      mean_shrubvol = (mean(shrub_vol_plot) %>% round(digits = 1)), 
                      sd_shrubvol = (sd(shrub_vol_plot) %>% round(digits = 1)), 
                      
                      mean_shrubpct = (mean(shrub_pct) %>% round(digits = 1)), 
                      sd_shrubpct = (sd(shrub_pct) %>% round(digits = 1)), 
                      
                      mean_pipj_pre_index = (mean(pipj_pre_index) %>% round(digits = 3)), 
                      sd_pipj_pre_index = (sd(pipj_pre_index) %>% round(digits = 3)),
                      
                      mean_conifer_index = (mean(conifer_index) %>% round(digits = 3)), 
                      sd_conifer_index = (sd(conifer_index) %>% round(digits = 3))
     )

summ_stats_group <- plotdata %>%
     group_by(loc_type, dist_cat) %>%
     dplyr::summarize(mean_sdl = (mean(n_c2) %>% round(digits = 1)), 
                      sd_sdl = (sd(n_c2) %>% round(digits = 1)),
                      med_sdl = (median(n_c2) %>% round(digits = 1)), 
                      
                      mean_sdl_pipj = (mean(pipj_n_c2) %>% round(digits = 1)), 
                      sd_sdl_pipj = (sd(pipj_n_c2) %>% round(digits = 1)),
                      med_sdl_pipj = (median(pipj_n_c2) %>% round(digits = 1)), 
                      
                      mean_shrubvol = (mean(shrub_vol_plot) %>% round(digits = 1)), 
                      sd_shrubvol = (sd(shrub_vol_plot) %>% round(digits = 1)), 
                      
                      mean_shrubpct = (mean(shrub_pct) %>% round(digits = 1)), 
                      sd_shrubpct = (sd(shrub_pct) %>% round(digits = 1)), 
                      
                      mean_pipj_pre_index = (mean(pipj_pre_index) %>% round(digits = 3)), 
                      sd_pipj_pre_index = (sd(pipj_pre_index) %>% round(digits = 3)),
                      
                      mean_conifer_index = (mean(conifer_index) %>% round(digits = 3)), 
                      sd_conifer_index = (sd(conifer_index) %>% round(digits = 3))
     )

summ_stats_loconly <- plotdata %>%
     group_by(loc) %>%
     dplyr::summarize(mean_sdl = (mean(n_c2) %>% round(digits = 1)), 
                      sd_sdl = (sd(n_c2) %>% round(digits = 1)),
                      med_sdl = (median(n_c2) %>% round(digits = 1)), 
                      max_sdl = (max(n_c2) %>% round(digits = 1)), 
                      
                      
                      mean_sdl_pipj = (mean(pipj_n_c2) %>% round(digits = 1)), 
                      sd_sdl_pipj = (sd(pipj_n_c2) %>% round(digits = 1)),
                      med_sdl_pipj = (median(pipj_n_c2) %>% round(digits = 1)), 
                      max_sdl_pipj = (max(n_c2) %>% round(digits = 1)), 
     )


list_of_datasets <- list("Summ_sdl" = summ_stats, "Summ_sdl_group" = summ_stats_group)
write.xlsx(list_of_datasets, file = "summary-data.xlsx")


# model tables

varnames <- c(`shrub_vol_plot_sc` = "Shrub Volume", 
              dist_pl_edge = "Distance from planted stand (m)", 
              conifer_index = "Large trees seed source (index)",  conifer_index_sc = "Large trees seed source (index)", 
              nr_conifer_index = "Nat. Regen seed source (index)", nr_conifer_index_sc = "Nat. Regen seed source (index)",  
              `(Intercept)` = "(Intercept)", 
              n_c1 = "Other natural regen (density)", n_c1_sc = "Other natural regen (density)", 
              gc_litter_sc = "Ground cover: litter (pct)",
              gc_li_cobb_sc = "Ground cover: litter and cobbles (pct)",
              
              # PIPJ
              pipj_pre_index = "Large trees seed source (index)", pipj_nr_index = "Nat. Regen seed source (index)",
              pipj_pre_index_sc ="Large trees seed source (index)", pipj_nr_index_sc = "Nat. Regen seed source (index)" )

tab_model(presence_pipj, density_pipj, transform = NULL, pred.labels = varnames, dv.labels = c("Presence (YP)", "Density (YP)"), collapse.ci = T)
tab_model(presence_all, density_all, transform = NULL, pred.labels = varnames, dv.labels = c("Presence (all species)", "Density (all species)"), collapse.ci=T)


tab_model(presence_pipj, presence_pipj_es, density_pipj, density_pipj_es, transform = NULL, digits = 3,
          pred.labels = varnames, dv.labels = c("Presence (YP)", "Presence w/o TNF (YP)",  "Density (YP)", "Density w/o TNF (YP)"),
          collapse.ci = T, file = "compare_mods.xlsx")
tab_model(presence_all,presence_all_es, density_all, density_all_es, transform = NULL, digits = 3, 
          pred.labels = varnames, dv.labels = c("Presence (all spp.)", "Presence w/o TNF (all spp.)", "Density (all spp.)", "Density w/o TNF (all spp.)"), 
          collapse.ci=T, file = "compare_mods.xlsx")


# prediction plots for logistic models: substitute pipj or "all spp" model names as necessary
pred_data <- data.frame(dist_pl_edge = seq(0, 70, length.out = 100), shrub_vol_plot_sc = 0, n_c1_sc = 0, conifer_index_sc = 0, nr_conifer_index_sc = 0, pipj_pre_index_sc = 0, pipj_nr_index_sc = 0, gc_litter_sc = 0, gc_li_cobb_sc = 0, transect = "ignore")

# predint1000 <- predictInterval(presence_all, newdata = pred_data , level = 0.95, n.sims = 10000, stat="median", type = "probability", include.resid.var = F )
predint1000 <- predictInterval(presence_pipj, newdata = pred_data , level = 0.95, n.sims = 10000, stat="median", type = "probability", include.resid.var = F )

unique_transects <- unique(plotdata$transect)

for (i in 1:length(unique_transects)) {
     
     transect_name = unique_transects[i]
     
     temp_pred <- pred_data %>%
          dplyr::mutate(transect = transect_name) 
     
     pred_data <- pred_data %>%
          # dplyr::mutate(newcol = predict(presence_all, temp_pred, re.form = NULL) %>% logit2prob()) %>%
          dplyr::mutate(newcol = predict(presence_pipj, temp_pred, re.form = NULL) %>% logit2prob()) %>%
          
          dplyr::rename(!! as.character(transect_name) := newcol) 
     
}

pred_data_ggplot <- pred_data %>%
     dplyr::select("dist_pl_edge") %>%
     cbind(predint1000) 

pred_data_ggbytransect <- pred_data %>%
     pivot_longer(
          cols = c(starts_with(c("CL", "BO", "BC"))),
          names_to = "transectnew", 
          values_to = "pred"
          
     ) %>%
     dplyr::select(-transect) %>%
     dplyr::rename(transect = transectnew) %>%
     dplyr::mutate(loc = substr(transect,1,2)) %>%
     dplyr::mutate(loc = case_when(
          loc == "BC" ~ "SNF", 
          loc == "CL" ~ "ENF", 
          loc == "BO" ~ "TNF"
     ))

loccolors = c("ENF"="#F79044FF", "SNF"="#DB5C68FF", "TNF"="#8B0AA5FF")

p <- ggplot(data = NULL) +
     geom_ribbon(alpha = 0.2, aes(x = dist_pl_edge, ymin = lwr, ymax = upr), data = pred_data_ggplot) +
     geom_line(aes(x = dist_pl_edge, y = fit), data = pred_data_ggplot, size = 1) +
     labs(x="Distance to planted stand (m)", y="Probability", color = "Location", linetype = "Location") + theme_classic() + 
     geom_line(data=pred_data_ggbytransect, aes(x = dist_pl_edge, y = pred, color = loc, group = transect, linetype = loc), alpha = .6) + scale_color_manual(values = loccolors) +
     theme(legend.position = c(0.1,0.20))
p

# shrub seedling comparison

shrubs <- plotdata %>%
     dplyr::group_by(loc) %>%
     dplyr::summarize(avght= mean(shrub_ht_cm, na.rm = T),
                      sdht = sd(shrub_ht_cm, na.rm = T), 
                      n = n()) %>%
     dplyr::mutate(seht = sdht / (sqrt(n))) %>%
     dplyr::mutate(type = "shrubs")

seedlings <- plotdata %>%
     dplyr::group_by(loc) %>%
     dplyr::summarize(avght= mean(avght_cm_nocade, na.rm = T),
                      sdht = sd(avght_cm_nocade, na.rm = T), 
                      n = n()) %>%
     dplyr::mutate(seht = sdht / (sqrt(n))) %>%
     dplyr::mutate(type = "seedlings")


shrubs_seedlings <- rbind(shrubs, seedlings) 

rm(shrubs, seedlings)

shrubht_to_plot <- shrubs_seedlings %>%
     dplyr::mutate(loc = case_when(
          loc == "BC" ~ "SNF", 
          loc == "CL" ~ "ENF", 
          loc == "BO" ~ "TNF"
     )) 

p <- ggplot(data = shrubht_to_plot, 
            aes(x = loc, y = avght, fill = type, color = loc ) ) + 
     geom_bar(stat = "identity",  position=position_dodge()) + scale_color_manual(values = loccolors) +
     geom_errorbar(aes(ymin = avght-seht, ymax = avght+seht), width = .2, position = position_dodge(.9)) +
     scale_fill_manual(values=c(seedlings = 'gray', shrubs = 'gray50' )) + theme_classic() +  theme(legend.position = c(.85,.8), legend.direction = "horizontal") +
     labs(x = "Location", y = "Average height (cm)", title = "Height of shrubs compared to seedlings", color = "Loc", fill = "")
p


# number of transects per location

transects_per_loc <- plotdata %>%
     group_by(loc, transect) %>%
     summarize(n = n())

# severity of sampled plots / locations

plot_locs <- st_read("~/projects/founder/data/mapping/sampled-founder-3310.gpkg")

plot_loc_buff <- st_buffer(plot_locs, 10)
plot_loc_buff100 <- st_buffer(plot_locs, 100)

# severity available from the USFS R5 geospatial data repository, https://www.fs.usda.gov/detail/r5/landmanagement/gis/?cid=STELPRDB5327833
# and clipped to project regions for ease of computation (--> "firesev-founder.gpkg")
firesev <- st_read("~/projects/founder/data/mapping/firesev-founder.gpkg")
firesev <- st_buffer(firesev, 0)

calc_sev_pct <- function(buffered_locs, sev_layer) {
     
     inters <- st_intersection(buffered_locs, sev_layer)
     
     inters <- inters %>% 
          dplyr::mutate(area_m2 = (st_area(inters) %>% round(digits = 0)))
     
     inters <- inters %>%
          group_by(VB_ID, BURNSEV) %>%
          dplyr::summarize(area_m2 = sum(area_m2)) %>%
          st_drop_geometry()
     
     inters_area <- inters %>%
          group_by(VB_ID) %>% 
          dplyr::summarize(tot_m2 = sum(area_m2))
     
     data <- inters %>%
          left_join(inters_area, by = "VB_ID") %>%
          dplyr::mutate(sev_pct = (area_m2 / tot_m2) %>% round(digits = 2))
     
     return(data)
     
}

plot_sev = calc_sev_pct(plot_loc_buff, firesev)
plotbuff100_sev = calc_sev_pct(plot_loc_buff100, firesev)

